/* eslint-disable no-console */
import signale from "signale";
import inquirer from "inquirer";
function createConsole() {
    return {
        debug: (message) => {
            signale.debug(message);
        },
        info: (message) => {
            signale.info(message);
        },
        warn: (message) => {
            signale.warn(message);
        },
        error: (message) => {
            signale.error(message);
        },
        fatal: (message) => {
            signale.fatal(message);
        },
        success: (message) => {
            signale.success(message);
        },
        print: (message) => {
            console.log(message || "");
        },
        table: (table, raw = false) => {
            if (raw) {
                table.forEach((value) => {
                    if (typeof value === "object" && value instanceof Array) {
                        console.log(value.join(","));
                    }
                    else {
                        console.log(value);
                    }
                });
            }
            else {
                console.log(table.toString());
            }
        },
        askYesNoQuestion: async (question, defaultValue) => {
            const answer = await inquirer.prompt([
                { type: "confirm", name: "q", message: question, default: defaultValue }
            ]);
            return answer.q;
        },
        askInputQuestion: async (question, defaultValue) => {
            const answer = await inquirer.prompt([
                {
                    type: "input",
                    name: "q",
                    message: question,
                    default: defaultValue
                }
            ]);
            return answer.q;
        },
        askListQuestion: async (question, choices, defaultValue) => {
            const answer = await inquirer.prompt([
                {
                    type: "list",
                    name: "q",
                    message: question,
                    default: defaultValue,
                    choices
                }
            ]);
            return answer.q;
        }
    };
}
export const appConsole = createConsole();
